<?php
/* vim: set expandtab sw=4 ts=4 sts=4: */
/**
 * The MERGE storage engine
 *
 * @package PhpMyAdmin-Engines
 */
if (! defined('PHPMYADMIN')) {
    exit;
}

/**
 * The MERGE storage engine
 *
 * @package PhpMyAdmin-Engines
 */
class PMA_StorageEngine_Merge extends PMA_StorageEngine
{
}

?>
